| Title: | GEISHA Expression Data |
|---|---|
| Description: | GEISHA expression data. These data are obtained from GEISHA <http://geisha.arizona.edu/geisha/downloads.jsp/>. |
| Authors: | Ramiro Magno [aut, cre] (ORCID: <https://orcid.org/0000-0001-5226-3441>) |
| Maintainer: | Ramiro Magno <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.1.0 |
| Built: | 2026-05-14 06:11:02 UTC |
| Source: | https://github.com/ramiromagno/geisha |
This dataset contains NCBI Gene ID, NCBI Gene Name, GEISHA ID, Ensembl ID, GO terms, embryo stages and tissue locations.
expression_txtexpression_txt
A tibble of 7 variables (columns):
ncbi_gene_idNCBI gene identifier.
ensembl_gene_idEnsembl gene identifier.
gene_nameNCBI gene name.
stagesHamilton-Hamburger stages.
locationsAnatomical location.
geisha_idGEISHA identifier.
gene_ontology_idGene ontology identifier.
Data set generation workflow can be found at the source of this package in
data-raw/data.R.
Original dataset from: http://geisha.arizona.edu/geisha/expression.txt.
This dataset contains NCBI Gene ID, NCBI Gene Name, GEISHA ID, embryo stages and tissue locations.
expression_xmlexpression_xml
A tibble of 5 variables (columns):
ncbi_gene_idNCBI gene identifier.
gene_nameNCBI gene name.
geisha_idGEISHA identifier.
stageHamilton-Hamburger stages.
locationAnatomical location.
Data set generation workflow can be found at the source of this package in
data-raw/data.R.
Original dataset from: http://geisha.arizona.edu/geisha/expression.xml.
This function will scrape on-the-fly GEISHA's downloads page and retrieve the date of last update of the to-be-downloaded files.
get_dates_of_last_update(files = download_files())get_dates_of_last_update(files = download_files())
files |
file names to whose update date is to be checked in the downloads page. |
Returns a tibble with one file per row.
This function retrieves those files available for download from the
downloads' page of the GEISHA website. These files are saved to
data-raw/ are meant to be used only by the package developer.
get_files(files = download_files())get_files(files = download_files())
files |
The name of the files to be downloaded. This parameter is set by default to download all available files. |
This function returns a character vector of Hamilton-Hamburguer (HH) stages.
hh_stages(hh_prefix = FALSE)hh_stages(hh_prefix = FALSE)
hh_prefix |
A logical indicating whether to include the prefix
|
A character vector of Hamilton-Hamburguer (HH) stages.
Date of last update of download files
last_updateslast_updates
A tibble of 2 variables:
fileFile name.
dateDate of last update by GEISHA.
This function reads data-raw/expression.txt as a tibble. This function
is meant to be used only by the developer of this package.
read_expression_txt()read_expression_txt()
Returns a tibble with the data present in expression.txt.
This function reads data-raw/expression.xml as a tibble. This function
is meant to be used only by the developer of this package.
read_expression_xml()read_expression_xml()
Returns a tibble with (part of) the data present in expression.xml.